@@ -23,11 +23,14 @@ from rqsdk.const import BASH_FILE, EXTRA_INDEX_URL
 
 
 def pip_install(full_name, index_url):
-    command = "install -U -i {} --extra-index-url {} {}".format(index_url, EXTRA_INDEX_URL, full_name)
+    proxy_url = os.environ.get('RQSDK_PROXY', "")
+    proxy_cmd = ""
+    if proxy_url:
+        proxy_cmd = "--proxy {}".format(proxy_url)
+    command = "install -U -i {} --extra-index-url {} {} {}".format(index_url, EXTRA_INDEX_URL, full_name, proxy_cmd)
     if os.environ.get("RQSDK_PYPI"):
-        command = "install -U -i {} {}".format(os.environ["RQSDK_PYPI"], full_name)
+        command = "install -U -i {} {} {}".format(os.environ["RQSDK_PYPI"], full_name, proxy_cmd)
         click.echo("pip {}".format(command))
-
     python_path = "\"{}\"".format(sys.executable)
     if sys.platform == "win32":
         end_help_msg = "& echo 请输入Enter继续..."
@@ -37,20 +40,26 @@ def pip_install(full_name, index_url):
         subprocess.check_call(["{} -m pip {} ".format(python_path, command)], shell=True)
 
 
-def update_bash_file(rqdatac_uri):
+def update_bash_file(variables, value):
     for _file in BASH_FILE:
         _path = os.path.join(os.path.expanduser("~"), _file)
         if not os.path.exists(_path):
             continue
         lines = open(_path, "r", encoding="utf8").readlines()
-        flag = False
-        for line in lines:
-            if "export RQDATAC2_CONF=" in line:
-                lines[lines.index(line)] = "export RQDATAC2_CONF={} \n".format(rqdatac_uri)
-                flag = True
+        changed = set()
 
-        if flag is False:
-            lines.append("export RQDATAC2_CONF={} \n".format(rqdatac_uri))
+        def update_bash(line):
+            nonlocal changed
+            for i in variables:
+                if "export {}=".format(i) in line:
+                    changed.add(i)
+                    return "export {}={} \n".format(i, value)
+            return line
 
+        lines = [update_bash(i) for i in lines.copy()]
+
+        for i in variables:
+            if not i in changed:
+                lines.append("export {}={} \n".format(i, value))
         with open(_path, "w", encoding="utf8")as f:
             f.writelines(lines)
